# Main program for Space Parcels.
"""
    Space Parcels -- main program.
    Copyright (C) 2005 Mathieu "Zig" Brethes <just.want.to.be@free.fr>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
"""
import pygame, os.path, random
from pygame.locals import *
from intro import intro
from title import title
import myglobals
from sound import SoundEngine

# Loads the configuration. Returns a 2-uple keys, stuff.
def loadConf():
	try:
		f = file("conf.txt", "r")
		all = f.read()
		f.close()
		lines = all.split("\n")
		keys = {}
		level= {}
		scores = []
		for l in lines:
			if len(l)>0:
				bits = l.split(":")
				if bits[0] == "k":
					keys[bits[1]] = int(bits[2])
				elif bits[0] == "l":
					level[bits[1]] = int(bits[2])
				elif bits[0] == "s":
					sndvol = float(bits[1])
					musvol = float(bits[2])
				elif bits[0] == "sc":
					scores.append((int(bits[1]),float(bits[2]),int(bits[3])))
	except IOError:
		keys = {"up":K_UP, "down":K_DOWN, "left":K_LEFT, "right":K_RIGHT, "shoot":K_RCTRL, "release":K_SPACE}
		level= {"stars":1,"boxprob":10,"lenplay":120,"portalsize":100}
		sndvol = 0.5
		musvol = 1.0
		scores = []
		print "Couldn't load conf file, using defaults."
	return (keys, level, (sndvol, musvol), scores)
		
	
def saveConf(keys, level, sndopts,scores):
	try:
		f = file("conf.txt","w")
		for k in keys.keys():
			f.write("k:%s:%d\n"%(k, keys[k]))
		for l in level.keys():
			f.write("l:%s:%d\n"%(l, level[l]))
		for s in scores:
			f.write("sc:%d:%f:%d\n"%(s))
		f.write("s:%f:%f"%(sndopts[0],sndopts[1]))
		f.close()
	except IOError:
		print "Couldn't write conf file."
				

if __name__ == '__main__':
	modules = pygame.init()
	print "Modules loaded: ", modules

	random.seed()

	keys, level, sndopts, scores= loadConf()

	myglobals.mySound = SoundEngine(sndopts[0], sndopts[1])
	myglobals.screen = pygame.display.set_mode([myglobals.DX, myglobals.DY],FULLSCREEN)
	pygame.event.set_blocked([MOUSEMOTION, MOUSEBUTTONUP, MOUSEBUTTONDOWN])
	pygame.mouse.set_visible(0)
	myglobals.screen.fill(0)
	myglobals.background = pygame.Surface([myglobals.DX, myglobals.DY])
	pygame.display.flip()

	intro()
	keys, level, scores = title(keys, level, scores)
	# we don't update sound info if sound was not available.
	if myglobals.mySound.isInitialized():
		sndopts = (myglobals.mySound.getSoundVolume(), myglobals.mySound.getMusicVolume())
	saveConf(keys, level, sndopts, scores)
