#!/usr/bin/python
"""
    Space Parcels -- Title screen
    Copyright (C) 2005 Mathieu "Zig" Brethes <just.want.to.be@free.fr>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
"""
# Title screen of the game Space Parcels

import pygame, os.path, random
from pygame.locals import *
from sound import SoundEngine
import myglobals
from menu import MainMenu, ScoreMenu
from game import Level

class Star(pygame.sprite.Sprite):
	global DX, DY, screen, background,mySound

	imageList = None

	def __init__(self):
		pygame.sprite.Sprite.__init__(self)	

		if Star.imageList is None:
			Star.imageList = [pygame.image.load(os.path.join("media","images","star_1.png")).convert(),
						pygame.image.load(os.path.join("media","images","star_2.png")).convert(),
						pygame.image.load(os.path.join("media","images","star_3.png")).convert()]
		self._frame = 0
		self.image = Star.imageList[self._frame]
		self._shininess = random.randint(1,9)
		# stars less shining go slower
		self._speed     = random.randint(10, 20) / (10 - self._shininess)
		self.rect       = self.image.get_rect()
		self.rect.topleft = (random.randint(0, DX -6), random.randint(0, DY - 6))

	def update(self):
		if random.randint(0, 10) > self._shininess:
			self._frame = (self._frame + 1) % 3
			_tmp = self.rect.topleft
			self.image = Star.imageList[self._frame]
			self.rect = self.image.get_rect()
			self.rect.topleft = _tmp
		self.rect.topleft = (self.rect.topleft[0] + self._speed, self.rect.topleft[1])
		if self.rect.topleft[0] > DX:
			self.rect.topleft = (0, random.randint(0, DY - 6))
			self._speed = random.randint(5,20)
			self._shininess = random.randint(1,9)

def title(keyOpts, levelOpts, theScores):
	global DX, DY, screen, background,mySound	

	DX=myglobals.DX
	DY=myglobals.DY
	screen=myglobals.screen
	background=myglobals.background
	mySound=myglobals.mySound

	bg     = pygame.image.load(os.path.join("media", "images", "title_00.png")).convert()
	bg.set_colorkey(pygame.color.Color("black"), RLEACCEL)

	bgc    = pygame.image.load(os.path.join("media", "images", "credits.png")).convert()

	titles = [pygame.image.load(os.path.join("media", "images", "titletext_00.png")).convert(),
			pygame.image.load(os.path.join("media", "images", "titletext_01.png")).convert(),
			pygame.image.load(os.path.join("media", "images", "titletext_02.png")).convert()]
	for t in titles:
		t.set_colorkey(pygame.color.Color("black"), RLEACCEL)
	titles.append(titles[1])
	tRect = pygame.Rect(250, 380, 388, 108)
	#background.fill(pygame.color.Color("white"))
	#background.blit(bg,[0,0])
	#screen.blit(bg, [0,0])
	index = -1

	stars = pygame.sprite.RenderUpdates()
	# one hundred shiny stars...
	for i in range(1, 100):
		stars.add(Star())


        C = pygame.time.Clock()
        C.tick()
	pygame.event.clear()
	endGame = False
	while not endGame:
		endTitle = False
                mySound.playTune("intro.wav")
		while not endTitle:
			for e in pygame.event.get():
				if e.type == KEYDOWN:
					M=MainMenu(screen, False, keyOpts, levelOpts)
					M.show()
					keyOpts, levelOpts = M.getAll()
					if M.hasQuit():
						endTitle = True
						endGame = True
						break
					if M.hasStarted():
						endTitle = True		
						
			pygame.event.pump()
			index += 0.1
			if index >= len(titles):
				index = 0
			screen.fill(0, tRect)
	
			stars.clear(screen, background)
			stars.update()
			rectlist = stars.draw(screen)
			screen.blit(bg,[0,0])
			screen.blit(titles[int(index)], [250, 380])		
			pygame.display.flip()
        	        C.tick(20)
		if not endGame:
			L = Level(keyOpts, levelOpts)
			ret = L.run()
			keyOpts = L.getKeys()
			score = (ret[0], ret[1], levelOpts["stars"])
			S = ScoreMenu(screen, theScores, score)
                        mySound.playTune("hiscores.wav")
			S.show()
			theScores = S.getScores()
        
        screen.blit(bgc,[0,0])
        pygame.display.flip()
        pygame.event.clear()
        time = C.tick()
        t = time
        mySound.playTune("credits.wav")
        while not pygame.event.peek([KEYDOWN, MOUSEBUTTONDOWN]) and t < time + 30000:
            pygame.event.pump()
            t += C.tick()

	return keyOpts, levelOpts, theScores
